@@ -24,7 +24,7 @@ class Country(ModelSQL, ModelView):
             ('code_uniq', 'UNIQUE(code)',
              'The code of the country must be unique!'),
         ]
-        self._order.insert(0, ('code', 'ASC'))
+        self._order.insert(0, ('name', 'ASC'))
 
     def search_rec_name(self, name, clause):
         ids = self.search([('code',) + clause[1:]], limit=1)
@@ -36,17 +36,7 @@ class Country(ModelSQL, ModelView):
         if 'code' in vals and vals['code']:
             vals = vals.copy()
             vals['code'] = vals['code'].upper()
-        new_id = super(Country, self).create(vals)
-        if 'module' in Transaction().context:
-            cursor = Transaction().cursor
-            cursor.execute('INSERT INTO ir_translation ' \
-                    '(name, lang, type, src, res_id, value, module, fuzzy) ' \
-                    'VALUES (%s, %s, %s, %s, %s, %s, %s, %s)',
-                    ('country.country,name', 'en_US', 'model',
-                        vals['name'], new_id, '',
-                        Transaction().context.get('module'),
-                        False))
-        return new_id
+        return super(Country, self).create(vals)
 
     def write(self, ids, vals):
         if 'code' in vals and vals['code']:
@@ -62,7 +52,7 @@ class Subdivision(ModelSQL, ModelView):
     _name = 'country.subdivision'
     _description = __doc__
     country = fields.Many2One('country.country', 'Country',
-            required=True)
+            required=True, select=1)
     name = fields.Char('Name', required=True, select=1)
     code = fields.Char('Code', required=True, select=1)
     type = fields.Selection([
